"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNetworkPort = void 0;
const integerRegex = /^0|[1-9]\d$/;
/**
 * @category Predicates
 * @param value The value to validate.
 * @param options Additional options (see {@link IsNetworkPort}).
 */
function isNetworkPort(value, options) {
    if (typeof value !== 'number' || !Number.isFinite(value) || value < 0 || !integerRegex.test(String(value))) {
        return false;
    }
    const port = value;
    const { allow_system_allocated, allow_system_ports } = Object.assign({ allow_system_allocated: true, allow_system_ports: true }, options);
    return (port <= 65535 &&
        value >= (allow_system_allocated ? 0 : 1) &&
        ((allow_system_allocated && port === 0) || allow_system_ports || port >= 1024));
}
exports.isNetworkPort = isNetworkPort;
